mirror of https://lore.kernel.org/lkml/
 help / color / mirror / Atom feed
From: Zhang Jiaming <jiaming@nfschina.com>
To: xiubli@redhat.com, idryomov@gmail.com, jlayton@kernel.org
Cc: ceph-devel@vger.kernel.org, linux-kernel@vger.kernel.org,
	liqiong@nfschina.com, renyu@nfschina.com,
	Zhang Jiaming <jiaming@nfschina.com>
Subject: [PATCH] netfs: Fix typo
Date: Fri,  1 Jul 2022 16:22:50 +0800	[thread overview]
Message-ID: <20220701082250.14935-1-jiaming@nfschina.com> (raw)

There is a typo (writeable) in comments and dout information.
Fix it.

Signed-off-by: Zhang Jiaming <jiaming@nfschina.com>
---
 fs/ceph/addr.c | 14 +++++++-------
 1 file changed, 7 insertions(+), 7 deletions(-)

diff --git a/fs/ceph/addr.c b/fs/ceph/addr.c
index 6dee88815491..083c5b6cae9e 100644
--- a/fs/ceph/addr.c
+++ b/fs/ceph/addr.c
@@ -565,7 +565,7 @@ static int writepage_nounlock(struct page *page, struct writeback_control *wbc)
 
 	dout("writepage %p idx %lu\n", page, page->index);
 
 	/* verify this is a writeable snap context */
 	snapc = page_snap_context(page);
 	if (!snapc) {
 		dout("writepage %p page %p not dirty?\n", inode, page);
@@ -573,7 +573,7 @@ static int writepage_nounlock(struct page *page, struct writeback_control *wbc)
 	}
 	oldest = get_oldest_context(inode, &ceph_wbc, snapc);
 	if (snapc->seq > oldest->seq) {
-		dout("writepage %p page %p snapc %p not writeable - noop\n",
+		dout("writepage %p page %p snapc %p not writable - noop\n",
 		     inode, page, snapc);
 		/* we should only noop if called by kswapd */
 		WARN_ON(!(current->flags & PF_MEMALLOC));
@@ -860,7 +860,7 @@ static int ceph_writepages_start(struct address_space *mapping,
 	} else if (!ceph_wbc.head_snapc) {
 		/* Do not respect wbc->range_{start,end}. Dirty pages
 		 * in that range can be associated with newer snapc.
 		 * They are not writeable until we write all dirty pages
 		 * associated with 'snapc' get written */
 		if (index > 0)
 			should_loop = true;
@@ -1219,7 +1219,7 @@ static int ceph_writepages_start(struct address_space *mapping,
 
 
 /*
  * See if a given @snapc is either writeable, or already written.
  */
 static int context_is_writeable_or_written(struct inode *inode,
 					   struct ceph_snap_context *snapc)
@@ -1265,18 +1265,18 @@ ceph_find_incompatible(struct page *page)
 
 		/*
 		 * this page is already dirty in another (older) snap
 		 * context!  is it writeable now?
 		 */
 		oldest = get_oldest_context(inode, NULL, NULL);
 		if (snapc->seq > oldest->seq) {
 			/* not writeable -- return it for the caller to deal with */
 			ceph_put_snap_context(oldest);
 			dout(" page %p snapc %p not current or oldest\n", page, snapc);
 			return ceph_get_snap_context(snapc);
 		}
 		ceph_put_snap_context(oldest);
 
 		/* yay, writeable, do it now (without dropping page lock) */
 		dout(" page %p snapc %p not current, but oldest\n", page, snapc);
 		if (clear_page_dirty_for_io(page)) {
 			int r = writepage_nounlock(page, NULL);
@@ -565,7 +565,7 @@ static int writepage_nounlock(struct page *page, struct writeback_control *wbc)
 	dout("writepage %p idx %lu\n", page, page->index);
 
-	/* verify this is a writeable snap context */
+	/* verify this is a writable snap context */
 	snapc = page_snap_context(page);
 	if (!snapc) {
@@ -860,7 +860,7 @@ static int ceph_writepages_start(struct address_space *mapping,
 		/* Do not respect wbc->range_{start,end}. Dirty pages
 		 * in that range can be associated with newer snapc.
-		 * They are not writeable until we write all dirty pages
+		 * They are not writable until we write all dirty pages
 		 * associated with 'snapc' get written */
 		if (index > 0)
@@ -1219,7 +1219,7 @@ static int ceph_writepages_start(struct address_space *mapping,
 
 /*
- * See if a given @snapc is either writeable, or already written.
+ * See if a given @snapc is either writable, or already written.
  */
 static int context_is_writeable_or_written(struct inode *inode,
@@ -1265,18 +1265,18 @@ ceph_find_incompatible(struct page *page)
 		/*
 		 * this page is already dirty in another (older) snap
-		 * context!  is it writeable now?
+		 * context!  is it writable now?
 		 */
 		oldest = get_oldest_context(inode, NULL, NULL);
@@ -1265,18 +1265,18 @@ ceph_find_incompatible(struct page *page)
 		oldest = get_oldest_context(inode, NULL, NULL);
 		if (snapc->seq > oldest->seq) {
-			/* not writeable -- return it for the caller to deal with */
+			/* not writable -- return it for the caller to deal with */
 			ceph_put_snap_context(oldest);
 			dout(" page %p snapc %p not current or oldest\n", page, snapc);
@@ -1265,18 +1265,18 @@ ceph_find_incompatible(struct page *page)
 		ceph_put_snap_context(oldest);
 
-		/* yay, writeable, do it now (without dropping page lock) */
+		/* yay, writable, do it now (without dropping page lock) */
 		dout(" page %p snapc %p not current, but oldest\n", page, snapc);
 		if (clear_page_dirty_for_io(page)) {
-- 
2.25.1


             reply	other threads:[~2022-07-01  8:25 UTC|newest]

Thread overview: 2+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2022-07-01  8:22 Zhang Jiaming [this message]
2022-07-01 11:09 ` Ilya Dryomov

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=20220701082250.14935-1-jiaming@nfschina.com \
    --to=jiaming@nfschina.com \
    --cc=ceph-devel@vger.kernel.org \
    --cc=idryomov@gmail.com \
    --cc=jlayton@kernel.org \
    --cc=linux-kernel@vger.kernel.org \
    --cc=liqiong@nfschina.com \
    --cc=renyu@nfschina.com \
    --cc=xiubli@redhat.com \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox

all inboxes | Powered by JetHome®